/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { RefObject, ReactElement } from 'react';

import { DataMask, DataMaskStateWithId, Filter } from '@superset-ui/core';
import { FilterBarOrientation } from 'src/dashboard/types';

export interface BaseFilterProps {
  orientation?: FilterBarOrientation;
  overflow?: boolean;
}

export interface FilterDividerProps extends BaseFilterProps {
  title: string;
  description: string;
}

export interface FilterControlProps extends BaseFilterProps {
  dataMaskSelected?: DataMaskStateWithId;
  filter: Filter & {
    dataMask?: DataMask;
  };
  icon?: ReactElement;
  focusedFilterId?: string;
  onFilterSelectionChange: (filter: Filter, dataMask: DataMask) => void;
  inView?: boolean;
  showOverflow?: boolean;
  parentRef?: RefObject<any>;
  setFilterActive?: (isActive: boolean) => void;
  validateStatus?: string;
}
